#!/usr/bin/env Rscript
# -*- mode: R -*-

# plot_aggregate_matrix: produces a plot of mean ATAC-seq signal
# around motifs, as generated by calling make_cut_matrix
# with the --aggregate-output option.


suppressMessages(library("RColorBrewer"))
suppressMessages(library("ggplot2"))
suppressMessages(library("grid"))
suppressMessages(library("gtools"))

argv <- commandArgs(TRUE)

bound_file = argv[1]
unbound_file = argv[2]
title = argv[3]
output_filename <- argv[4]

bound = read.delim(file=bound_file, header=TRUE, sep="\t")
bound$Bound = "Bound"
bound$Bin <- as.character(bound$Bin)

unbound = read.delim(file=unbound_file, header=TRUE, sep="\t")
unbound$Bound = "Unbound"
unbound$Bin <- as.character(unbound$Bin)

df <- rbind(bound, unbound)
df$Bin <- factor(df$Bin)
df$Bin <- factor(df$Bin, levels=mixedsort(levels(df$Bin)))
df$Strand <- as.factor(df$Strand)

p <- ggplot(df, aes(x=Position, y=MeanCutPointCount, colour=Strand))
p <- p + geom_line(alpha=0.75) + facet_grid(Bin ~ Bound, scales="free") + ggtitle(title)
p <- p + xlab('Relative Position') + ylab('ATAC-seq mean signal per region')
p <- p + theme_bw(base_size=10)
p <- p + theme(
  strip.background = element_rect(fill="gray90", colour=FALSE),
  panel.border = element_rect(colour="gray90"),
  panel.margin = unit(1, "lines"),
  plot.title=element_text(vjust=1),
  axis.title.x=element_text(vjust=-0.5),
  axis.title.y=element_text(vjust=1)
)
p <- p + scale_fill_brewer(palette="Dark2")

ggsave(p, file=output_filename, width=11, height=8.5, units="in")

cat(paste("Plot written to", output_filename, "\n"))
